// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services'])

.run(["$ionicPlatform",function($ionicPlatform) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
      cordova.plugins.Keyboard.disableScroll(true);

    }
    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }
  });
}])

.config(["$stateProvider", "$urlRouterProvider", "$ionicConfigProvider",function($stateProvider, $urlRouterProvider, $ionicConfigProvider) {

  /* 这里是配置一些不同平台的样式问题*/
  $ionicConfigProvider.platform.ios.tabs.style('standard');

  /*底部菜单栏位置。android的默认风格会跑到顶上去。这里固定在底部*/
  //$ionicConfigProvider.platform.ios.tabs.position('bottom');
  $ionicConfigProvider.platform.android.tabs.style('standard');
  $ionicConfigProvider.platform.android.tabs.position('bottom');

  /*导航栏标题居中*/
  //$ionicConfigProvider.platform.ios.navBar.alignTitle('center'); 
  $ionicConfigProvider.platform.android.navBar.alignTitle('center');

  /*返回按钮的样式*/
  $ionicConfigProvider.platform.ios.backButton.previousTitleText('').icon('ion-ios-arrow-thin-left');
  $ionicConfigProvider.platform.android.backButton.previousTitleText('').icon('ion-android-arrow-back');

  /* 页面切换效果，看选择哪个平台的风格。可选参数为"ios","anroid"，"none"  */
  $ionicConfigProvider.platform.ios.views.transition('none');
  $ionicConfigProvider.platform.android.views.transition('android');

  /*使用原生滚动*/
  $ionicConfigProvider.scrolling.jsScrolling(false);

  /* URL路由，可在这里根据url指定使用模板*/
  $stateProvider

  // setup an abstract state for the tabs directive
    .state('tab', {
    url: '/tab',
    abstract: true,
    templateUrl: 'templates/tabs.html',
  })

  // Each tab has its own nav history stack:

  .state('tab.home', {
    url: '/home',
    views: {
      'tab-home': {
        templateUrl: 'templates/home/tab-home.html',
        controller: 'HomeCtrl'
      }
    }
  })

  .state('tab.home.toptab1', {
    url: '/toptab1',
    views: {
      'home-toptab1': {
        templateUrl: 'templates/home/toptab1.html',
        controller: 'HomeToptab1Ctrl'
      }
    }
  })

  .state('tab.home.toptab2', {
    url: '/toptab2',
    views: {
      'home-toptab2': {
        templateUrl: 'templates/home/toptab2.html',
        controller: 'HomeToptab2Ctrl'
      }
    }
  })

  .state('tab.home.toptab3', {
    url: '/toptab3',
    views: {
      'home-toptab3': {
        templateUrl: 'templates/home/toptab3.html',
        controller: 'HomeToptab3Ctrl'
      }
    }
  })

  .state('subject-detail', {
    cache: false,
    url: '/subject-detail/:sub_id',
    templateUrl: 'templates/subject/detail.html',
    controller: 'SubjectDetailCtrl'
  })

  .state('add-subject', {
    cache: false,
    url: '/add-subject/:cat_id',
    templateUrl: 'templates/subject/add-subject.html',
    controller: 'AddSubjectCtrl'
  })

  .state('tab.message', {
    url: '/message',
    views: {
      'tab-message': {
        templateUrl: 'templates/message/tab-message.html',
        controller: 'MessageCtrl'
      }
    }
  })

  .state('tab.message-detail', {
    url: '/message/:chatId',
    views: {
      'tab-message': {
        templateUrl: 'templates/message/message-detail.html',
        controller: 'MessageDetailCtrl'
      }
    }
  })

  .state('tab.find', {
    url: '/find',
    views: {
      'tab-find': {
        templateUrl: 'templates/find/tab-find.html',
        controller: 'FindCtrl'
      }
    }
  })

  .state('tab.my', {
    cache:false,
    url: '/my',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/tab-my.html',
        controller: 'MyCtrl'
      }
    }
  })

  .state('tab.my-profile', {
    url: '/my-profile',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/profile.html',
        controller: 'MyProfileCtrl'
      }
    }
  })

  .state('tab.my-sina-detail', {
    url: '/my-sina-detail/:sina_uid',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/sina-detail.html',
        controller: 'SinaDetailCtrl'

      }
    }
  })

  .state('tab.my-follow-subject', {
    url: '/my-follow-subject',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/follow-subject.html',
        controller: 'MyFollowSubjectCtrl'
      }
    }
  })

  .state('tab.my-subject', {
    url: '/my-subject',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/subject.html',
        controller: 'MySubjectCtrl'
      }
    }
  })

  .state('tab.my-follow-subject-detail', {
    url: '/my-follow-subject-detail/:chatId',
    views: {
      'tab-my': {
        templateUrl: 'templates/subject/detail.html',
        controller: 'SubjectDetailCtrl'
      }
    }
  })

  .state('tab.my-subject-detail', {
    url: '/my-subject-detail/:chatId',
    views: {
      'tab-my': {
        templateUrl: 'templates/subject/detail.html',
        controller: 'SubjectDetailCtrl'
      }
    }
  })

  .state('tab.my-setting', {
    cache:false,
    url: '/my-setting',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/setting.html',
        controller: 'MySettingCtrl'
      }
    }
  })

  .state('tab.my-feedback', {
    cache:false,
    url: '/my-feedback',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/feedback.html',
        controller: 'MyFeedbackCtrl'
      }
    }
  })

  .state('tab.my-about', {
    cache:false,
    url: '/my-about',
    views: {
      'tab-my': {
        templateUrl: 'templates/my/about.html',
      }
    }
  })

  .state('tab.manage', {
    url: '/manage',
    views: {
      'tab-my': {
        templateUrl: 'templates/manage/index.html',
        controller: 'ManageCtrl'
      }
    }
  })

  .state('tab.manage-setting', {
    url: '/manage-setting',
    views: {
      'tab-my': {
        templateUrl: 'templates/manage/setting.html',
        controller: 'ManageSettingCtrl'
      }
    }
  })

  .state('tab.manage-keyword', {
    url: '/manage-keyword',
    views: {
      'tab-my': {
        templateUrl: 'templates/manage/keyword.html',
        controller: 'ManageKeywordCtrl'
      }
    }
  })

  .state('tab.manage-deleter', {
    url: '/manage-deleter',
    views: {
      'tab-my': {
        templateUrl: 'templates/manage/deleter.html',
        controller: 'ManageDeleterCtrl'
      }
    }
  })

  .state('tab.manage-admin', {
    url: '/manage-admin',
    views: {
      'tab-my': {
        templateUrl: 'templates/manage/admin.html',
        controller: 'ManageAdminCtrl'
      }
    }
  })

  .state('tab.manage-auth', {
    cache:false,
    url: '/manage-auth',
    views: {
      'tab-my': {
        templateUrl: 'templates/manage/auth.html',
        controller: 'ManageAuthCtrl'
      }
    }
  })

  .state('tab.manage-auth-detail', {
    url: '/manage-auth-detail',
    views: {
      'tab-my': {
        templateUrl: 'templates/manage/auth-detail.html',
        controller: 'ManageAuthDetailCtrl'
      }
    }
  })

  .state('callback', {
    url: '/callback',
    templateUrl: 'templates/callback.html',
    controller: 'CallBackCtrl'
    })

  .state('login', {
    cache:false,
    url: '/login',
    templateUrl: 'templates/login.html',
    controller: 'LoginCtrl'
    })

  // if none of the above states are matched, use this as the fallback
  // 设置默认主页
  $urlRouterProvider.otherwise('/tab/home');

}]);

angular.module('starter')
  .config(["$provide",function($provide) {
    $provide.constant(
      'AppConfig', {
        api_key: "1011513315113",
        api_secret: "1476c28fdd679dffd8ce110a6480cc4f",
        version: "1.0.0",
        name: "Yard",
        debug: false,
        host: "http://yard.star7th.com/server",
        login_url:"http://yard.star7th.com/server/passport/user/login",
        account_id: "1",
        toptab1_cat_id: "1",
        toptab1_cat_name: "匿名微博",
        toptab2_cat_id: "2",
        toptab2_cat_name: "交易市场",
        toptab3_cat_id: "3",
        toptab3_cat_name: "树洞深处",
      }
    );
  }])

.config([
  '$compileProvider',
  function ($compileProvider) {
      //  Default imgSrcSanitizationWhitelist: /^\s*((https?|ftp|file|blob):|data:image\/)/
      //  chrome-extension: will be added to the end of the expression
      $compileProvider.imgSrcSanitizationWhitelist(/^\s*((https?|ftp|wxlocalresource|weixin|file|blob|chrome-extension):|data:image\/)/);
  }
]);

angular.module('starter.controllers', ['starter.services', 'ionic', 'ngFileUpload']);
angular.module('starter.services', ['ionic', 'ngResource']);