angular.module('starter.services')

/* 封装了公用的http请求方法*/
.factory('httpq', ["$q", "$ionicLoading", "$http", "$ionicPopup", "AppConfig","UserInfo",function($q, $ionicLoading, $http, $ionicPopup, AppConfig,UserInfo) {

  var param = function(obj) {
    var query = '',
      name, value, fullSubName, subName, subValue, innerObj, i;

    for (name in obj) {
      value = obj[name];

      if (value instanceof Array) {
        for (i = 0; i < value.length; ++i) {
          subValue = value[i];
          fullSubName = name + '[' + i + ']';
          innerObj = {};
          innerObj[fullSubName] = subValue;
          query += param(innerObj) + '&';
        }
      } else if (value instanceof Object) {
        for (subName in value) {
          subValue = value[subName];
          fullSubName = name + '[' + subName + ']';
          innerObj = {};
          innerObj[fullSubName] = subValue;
          query += param(innerObj) + '&';
        }
      } else if (value !== undefined && value !== null)
        query += encodeURIComponent(name) + '=' + encodeURIComponent(value) + '&';
    }

    return query.length ? query.substr(0, query.length - 1) : query;
  };

  return {
    /**
     * [发起http请求]
     * @param  {[string]} method_type  [请求方法]
     * @param  {[string]} url          [请求url]
     * @param  {[string]} request_data [请求数据]
     * @param  {[bool]} hideLoading  [是否隐藏loading动画]
     * @param  {[bool]} hideAlert    [是否隐藏错误提示框]
     * @return {[Object]}              
     */
    request: function(method_type, url, request_data, hideLoading, hideAlert) {
      request_data.api_key = AppConfig.api_key;
      var timestamp = new Date().getTime();
      request_data.timestamp = timestamp;
      request_data.api_token = hex_md5(timestamp + AppConfig.api_secret);
      if(!request_data.user_token)request_data.user_token = UserInfo.getToken();
      request_data = angular.isObject(request_data) && String(request_data) !== '[object File]' ? param(request_data) : request_data;
      //console.log(request_data);
      //显示加载动画，最多30秒
      if (!hideLoading) {
        $ionicLoading.show({
          "duration": 30000
        })
      };
      var defer = $q.defer(); //声明延后执行
      $http({
        method: method_type,
        url: url,
        data: request_data,
        timeout: 30000,
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
        },
      }).

      success(function(data, status) {
        if (!hideLoading) {
          $ionicLoading.hide()
        }; //隐藏Loading
        defer.resolve(data); //声明执行成功
      }).

      error(function(data, status) {
        if (!hideLoading) {
          $ionicLoading.hide()
        }; //隐藏Loading
        //显示错误提示
        if (!hideAlert) {
          $ionicPopup.alert({
            title: "提示",
            template: "网络错误，请稍后再试"
          });
        }
        defer.reject(data); //声明执行失败
      });
      return defer.promise; //返回承诺，返回获取数据的API
    },

    get: function(url, request_data, hideLoading, hideAlert) {
      return this.request("GET", url, request_data, hideLoading, hideAlert);
    },

    post: function(url, request_data, hideLoading, hideAlert) {
      return this.request("POST", url, request_data, hideLoading, hideAlert);
    }
  }
}])


.factory('Deleter', ["httpq", "$q", "AppConfig",function(httpq, $q, AppConfig) {
  var admins = [];

  var add = function(name  , cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/Deleter/add", {
        "name": name,
        "account_id": AppConfig.account_id,
        "cat_id" : cat_id
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  var deleteUser = function(id  , cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/Deleter/delete", {
        "id": id,
        "account_id": AppConfig.account_id,
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  var getList = function(cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/Deleter/getList", {
        "account_id": AppConfig.account_id,
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  return {
    add: add,
    getList: getList,
    deleteUser: deleteUser,

  };
}])

.factory('Keyword', ["httpq", "$q", "AppConfig",function(httpq, $q, AppConfig) {
  var keywords = [];

  var add = function(keyword  , cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/keyword/add", {
        "keyword": keyword,
        "account_id": AppConfig.account_id,
        "cat_id" : cat_id
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  var deleteKeyword = function(id  , cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/keyword/delete", {
        "id": id,
        "account_id": AppConfig.account_id,
        "cat_id" : cat_id
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  var getList = function(cat_id,page, count) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/keyword/getList", {
        "page": page,
        "count": count,
        "account_id": AppConfig.account_id,
        "cat_id" : cat_id
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  return {
    add: add,
    getList: getList,
    deleteKeyword: deleteKeyword,

  };
}])

.factory('ManageAdmin', ["httpq", "$q", "AppConfig",function(httpq, $q, AppConfig) {
  var admins = [];

  var add = function(name  , cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/ManageAdmin/add", {
        "name": name,
        "account_id": AppConfig.account_id,
        "cat_id" : cat_id
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  var deleteAdmin = function(id  , cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/ManageAdmin/delete", {
        "id": id,
        "account_id": AppConfig.account_id,
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  var getList = function(cat_id) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/ManageAdmin/getList", {
        "account_id": AppConfig.account_id,
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  return {
    add: add,
    getList: getList,
    deleteAdmin: deleteAdmin,

  };
}])

.factory('Chats', function() {
  // Might use a resource here that returns a JSON array

  // Some fake testing data
  var chats = [{
    id: 0,
    name: 'Ben Sparrow',
    lastText: 'You on your way?',
    face: 'http://tp4.sinaimg.cn/1709381783/180/5653400725/1'
  }, {
    id: 1,
    name: 'Max Lynx',
    lastText: 'Hey, it\'s me',
    face: 'http://tp4.sinaimg.cn/1709381783/180/5653400725/1'
  }, {
    id: 2,
    name: 'Adam Bradleyson',
    lastText: 'I should buy a boat',
    face: 'http://tp4.sinaimg.cn/1709381783/180/5653400725/1'
  }, {
    id: 3,
    name: 'Perry Governor',
    lastText: 'Look at my mukluks!',
    face: 'http://tp4.sinaimg.cn/1709381783/180/5653400725/1'
  }, {
    id: 4,
    name: 'Mike Harrington',
    lastText: 'This is wicked good ice cream.',
    face: 'http://tp4.sinaimg.cn/1709381783/180/5653400725/1'
  }];

  return {
    all: function() {
      return chats;
    },
    remove: function(chat) {
      chats.splice(chats.indexOf(chat), 1);
    },
    get: function(chatId) {
      for (var i = 0; i < chats.length; i++) {
        if (chats[i].id === parseInt(chatId)) {
          return chats[i];
        }
      }
      return null;
    }
  };
})

.factory('Subjects', ["httpq", "$q", "AppConfig",function(httpq, $q, AppConfig) {
  var subjects = [];

  var send = function(cat_id, text, pic_url) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/subject/send", {
        "cat_id": cat_id,
        "account_id": AppConfig.account_id,
        "text": text,
        "pic_url": pic_url
      }
    );
    promise.then(function(data) {
      defer.resolve(data); //声明执行成功
    }, function(error) {
      //不成功
      defer.reject(data); //声明执行失败
    });
    return defer.promise; //返回承诺，返回获取数据的API
  }

  var getListByCatId = function(cat_id, page, count) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/subject/accountList", {
        "cat_id": cat_id,
        "page": page,
        "count": count,
        "account_id": AppConfig.account_id
      }, true
    );
    promise.then(function(data) {
      subjects[cat_id] = data.data;
      defer.resolve(data); //声明执行成功
    }, function(error) {
      //不成功
      defer.reject(data); //声明执行失败
    });
    return defer.promise; //返回承诺，返回获取数据的API
  }

  var getMyList = function(page, count) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/subject/myList", {
        "page": page,
        "count": count
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }

  var getMyFollowList = function(page, count) {
    var defer = $q.defer(); //声明延后执行
    var promise = httpq.post(
      AppConfig.host + "/api/subject/followList", {
        "page": page,
        "count": count
      }, true
    );
    return promise; //返回承诺，返回获取数据的API
  }
  return {
    //发布主题
    send: send,
    //获取主题列表
    getListByCatId: getListByCatId,
    getMyList: getMyList,
    getMyFollowList: getMyFollowList,
    all: function() {
      return subjects;
    },
    cleanAll: function() {
      subjects = [];
    },
    remove: function(sub_id) {
      subjects.splice(subjects.indexOf(sub_id), 1);
    },
    //从缓存中获取单条主题信息
    getFromCache: function(sub_id) {
      for (x in subjects) {
        for (y in subjects[x]) {
          if (subjects[x][y]['sub_id'] == sub_id) {
            return subjects[x][y];
          };
        }
      }
      return false;

    },
    //从网络获取单条主题信息
    get: function(sub_id) {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/show", {
          "sub_id": sub_id
        }
      );
      return promise
    },

    delete: function(sub_id) {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/delete", {
          "sub_id": sub_id
        }
      );
      return promise
    },
    block: function(sub_id) {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/block", {
          "sub_id": sub_id
        }
      );
      return promise
    },

    follow: function(sub_id) {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/follow", {
          "sub_id": sub_id
        }
      );
      return promise
    },
    blacklist: function(sub_id) {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/blacklist", {
          "sub_id": sub_id
        }
      );
      return promise
    },

    showAuthor: function(sub_id) {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/showAuthor", {
          "sub_id": sub_id
        }
      );
      return promise
    },

    //获取七牛上传token
    getQiniuToken: function() {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/getQiniuToken", {},
        true, true
      );
      return promise
    },

    //发布评论
    send_comment: function(sub_id, reply_com_id, text) {
      var promise = httpq.post(
        AppConfig.host + "/api/comment/send", {
          "sub_id": sub_id,
          "reply_com_id": reply_com_id,
          "text": text
        }
      );
      return promise;
    },
    //获取评论列表
    getCommentList: function(sub_id, page, count) {
      var promise = httpq.post(
        AppConfig.host + "/api/comment/commentList", {
          "sub_id": sub_id,
          "page": page,
          "count": count
        }
      );
      return promise;
    },


    //给主题点赞或者取消点赞||给主题点踩或者取消点踩
    like: function(sub_id, field, action) {
      var promise = httpq.post(
        AppConfig.host + "/api/subject/like", {
          "sub_id": sub_id,
          "field": field,
          "action": action
        }
      );
      return promise;
    },

    //更新某条主题的数目缓存（赞/踩/评论数目）
    update_subject_count: function(subject) {
      if (subjects) {
        for (x in subjects) {
          for (y in subjects[x]) {
            if (subjects[x][y]['sub_id'] == subject['sub_id']) {
              subjects[x][y]['like_count'] = subject['like_count'];
              subjects[x][y]['unlike_count'] = subject['unlike_count'];
              subjects[x][y]['current_user_like'] = subject['current_user_like'];
              subjects[x][y]['current_user_unlike'] = subject['current_user_unlike'];
              subjects[x][y]['comment_count'] = subject['comment_count'];
            };
          }
        }
      };

      return false;
    }

  };
}])

/* 封装了本地用户信息的一些操作*/
.factory('UserInfo', ["$q", "$ionicLoading", "$http","$state", "$ionicPopup", "AppConfig","$location",function($q, $ionicLoading, $http,$state, $ionicPopup, AppConfig,$location) {

  //判断登录
  var checkLogin = function(){
    user_info = getInfo();
    if (user_info) {
      return true;
    }
    else{
       var confirmPopup = $ionicPopup.confirm({
         title: '温馨提示',
         template: '你尚未登录，去登录吗？',
         cancelText :"忽略",
         okText :"走起"
       });
       confirmPopup.then(function(res) {
         if(res) {
           //LoginUrl = getLoginUrl();
           //window.location.href = LoginUrl;
           $state.go("login");
         } else {
         }
       });
    }
  }

  var exitLogin = function(){
    localStorage.user_info = '';
    localStorage.account_role = '';
    localStorage.user_token = '';
    window.location.href = "#/tab/home/toptab1";
  }

  //过期、重新登录
  var reLogin = function(){
     var confirmPopup = $ionicPopup.confirm({
       title: '温馨提示',
       template: '你的登录信息已过期，去登录吗？',
       cancelText :"忽略",
       okText :"走起"
     });
     confirmPopup.then(function(res) {
       if(res) {
         //LoginUrl = getLoginUrl();
         //window.location.href = LoginUrl;
         $state.go("login");
       } else {
       }
     });
  }


  //判断登录
  var getLoginUrl = function(){      
      currenr_url = $location.absUrl();
      currenr_base_url = currenr_url.split("#");
      callback_url = encodeURIComponent(currenr_base_url[0]+"#/callback");
      return AppConfig.login_url+"?callback_url="+callback_url;
  }


  //获取用户信息或者信息的某个字段
  var getInfo = function(field){      
    user_info = localStorage.user_info;
    if (user_info) {
      if (field) {
          if (user_info[field]) {
            return user_info[field] ;
          };
      }else{
        return JSON.parse(user_info) ;
      }
    }
    return false;
  }
  //设置/更新用户信息或者某个字段
  var setInfo = function(user_info ,field){
    if (user_info) {
      //如果是对象，则将其转化为字符串
      if (angular.isObject(user_info)) {
        user_info = JSON.stringify(user_info)
      };
      localStorage.user_info = user_info ;
    }
    if (field) {
      localStorage.user_info[field] = field ;
    };
  }

  var getToken = function(){
    return localStorage.user_token;
  }

  var setToken = function(user_token){
    return localStorage.user_token = user_token;
  }

  var getAccountRole = function(){
    return localStorage.account_role;
  }

  var setAccountRole = function(account_role){
    return localStorage.account_role = account_role;
  }


  return {
    checkLogin : checkLogin,
    exitLogin : exitLogin,
    getLoginUrl : getLoginUrl,
    getInfo : getInfo,
    setInfo : setInfo,
    setToken : setToken,
    getToken : getToken,
    reLogin : reLogin,
    getAccountRole : getAccountRole,
    setAccountRole : setAccountRole,
  }
}])